==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/Systemuserprofiles.java <==
package microsoft.dynamics.crm.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "systemuserprofileid", 
    "versionnumber", 
    "systemuserid", 
    "fieldsecurityprofileid"})
@JsonInclude(Include.NON_NULL)
public class Systemuserprofiles extends Crmbaseentity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.systemuserprofiles";
    }

    @JsonProperty("systemuserprofileid")
    protected String systemuserprofileid;

    @JsonProperty("versionnumber")
    protected Long versionnumber;

    @JsonProperty("systemuserid")
    protected String systemuserid;

    @JsonProperty("fieldsecurityprofileid")
    protected String fieldsecurityprofileid;

    protected Systemuserprofiles() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderSystemuserprofiles() {
        return new Builder();
    }

    public static final class Builder {
        private String systemuserprofileid;
        private Long versionnumber;
        private String systemuserid;
        private String fieldsecurityprofileid;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder systemuserprofileid(String systemuserprofileid) {
            this.systemuserprofileid = systemuserprofileid;
            this.changedFields = changedFields.add("systemuserprofileid");
            return this;
        }

        public Builder versionnumber(Long versionnumber) {
            this.versionnumber = versionnumber;
            this.changedFields = changedFields.add("versionnumber");
            return this;
        }

        public Builder systemuserid(String systemuserid) {
            this.systemuserid = systemuserid;
            this.changedFields = changedFields.add("systemuserid");
            return this;
        }

        public Builder fieldsecurityprofileid(String fieldsecurityprofileid) {
            this.fieldsecurityprofileid = fieldsecurityprofileid;
            this.changedFields = changedFields.add("fieldsecurityprofileid");
            return this;
        }

        public Systemuserprofiles build() {
            Systemuserprofiles _x = new Systemuserprofiles();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.systemuserprofiles";
            _x.systemuserprofileid = systemuserprofileid;
            _x.versionnumber = versionnumber;
            _x.systemuserid = systemuserid;
            _x.fieldsecurityprofileid = fieldsecurityprofileid;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && systemuserprofileid != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(systemuserprofileid.toString()));
        }
    }

    @Property(name="systemuserprofileid")
    @JsonIgnore
    public Optional<String> getSystemuserprofileid() {
        return Optional.ofNullable(systemuserprofileid);
    }

    public Systemuserprofiles withSystemuserprofileid(String systemuserprofileid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("systemuserprofileid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.systemuserprofileid = systemuserprofileid;
        return _x;
    }

    @Property(name="versionnumber")
    @JsonIgnore
    public Optional<Long> getVersionnumber() {
        return Optional.ofNullable(versionnumber);
    }

    public Systemuserprofiles withVersionnumber(Long versionnumber) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("versionnumber");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.versionnumber = versionnumber;
        return _x;
    }

    @Property(name="systemuserid")
    @JsonIgnore
    public Optional<String> getSystemuserid() {
        return Optional.ofNullable(systemuserid);
    }

    public Systemuserprofiles withSystemuserid(String systemuserid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("systemuserid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.systemuserid = systemuserid;
        return _x;
    }

    @Property(name="fieldsecurityprofileid")
    @JsonIgnore
    public Optional<String> getFieldsecurityprofileid() {
        return Optional.ofNullable(fieldsecurityprofileid);
    }

    public Systemuserprofiles withFieldsecurityprofileid(String fieldsecurityprofileid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("fieldsecurityprofileid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.fieldsecurityprofileid = fieldsecurityprofileid;
        return _x;
    }

    public Systemuserprofiles withUnmappedField(String name, String value) {
        Systemuserprofiles _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Systemuserprofiles patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Systemuserprofiles _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Systemuserprofiles put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Systemuserprofiles _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Systemuserprofiles _copy() {
        Systemuserprofiles _x = new Systemuserprofiles();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.systemuserprofileid = systemuserprofileid;
        _x.versionnumber = versionnumber;
        _x.systemuserid = systemuserid;
        _x.fieldsecurityprofileid = fieldsecurityprofileid;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Systemuserprofiles[");
        b.append("systemuserprofileid=");
        b.append(this.systemuserprofileid);
        b.append(", ");
        b.append("versionnumber=");
        b.append(this.versionnumber);
        b.append(", ");
        b.append("systemuserid=");
        b.append(this.systemuserid);
        b.append(", ");
        b.append("fieldsecurityprofileid=");
        b.append(this.fieldsecurityprofileid);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-microsoft-dynamics-0.1.58-sources.jar: microsoft/dynamics/crm/entity/Systemuserprofiles.java <==
package microsoft.dynamics.crm.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "systemuserprofileid", 
    "versionnumber", 
    "systemuserid", 
    "fieldsecurityprofileid"})
@JsonInclude(Include.NON_NULL)
public class Systemuserprofiles extends Crmbaseentity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.systemuserprofiles";
    }

    @JsonProperty("systemuserprofileid")
    protected String systemuserprofileid;

    @JsonProperty("versionnumber")
    protected Long versionnumber;

    @JsonProperty("systemuserid")
    protected String systemuserid;

    @JsonProperty("fieldsecurityprofileid")
    protected String fieldsecurityprofileid;

    protected Systemuserprofiles() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderSystemuserprofiles() {
        return new Builder();
    }

    public static final class Builder {
        private String systemuserprofileid;
        private Long versionnumber;
        private String systemuserid;
        private String fieldsecurityprofileid;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder systemuserprofileid(String systemuserprofileid) {
            this.systemuserprofileid = systemuserprofileid;
            this.changedFields = changedFields.add("systemuserprofileid");
            return this;
        }

        public Builder versionnumber(Long versionnumber) {
            this.versionnumber = versionnumber;
            this.changedFields = changedFields.add("versionnumber");
            return this;
        }

        public Builder systemuserid(String systemuserid) {
            this.systemuserid = systemuserid;
            this.changedFields = changedFields.add("systemuserid");
            return this;
        }

        public Builder fieldsecurityprofileid(String fieldsecurityprofileid) {
            this.fieldsecurityprofileid = fieldsecurityprofileid;
            this.changedFields = changedFields.add("fieldsecurityprofileid");
            return this;
        }

        public Systemuserprofiles build() {
            Systemuserprofiles _x = new Systemuserprofiles();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.systemuserprofiles";
            _x.systemuserprofileid = systemuserprofileid;
            _x.versionnumber = versionnumber;
            _x.systemuserid = systemuserid;
            _x.fieldsecurityprofileid = fieldsecurityprofileid;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && systemuserprofileid != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(systemuserprofileid.toString()));
        }
    }

    @Property(name="systemuserprofileid")
    @JsonIgnore
    public Optional<String> getSystemuserprofileid() {
        return Optional.ofNullable(systemuserprofileid);
    }

    public Systemuserprofiles withSystemuserprofileid(String systemuserprofileid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("systemuserprofileid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.systemuserprofileid = systemuserprofileid;
        return _x;
    }

    @Property(name="versionnumber")
    @JsonIgnore
    public Optional<Long> getVersionnumber() {
        return Optional.ofNullable(versionnumber);
    }

    public Systemuserprofiles withVersionnumber(Long versionnumber) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("versionnumber");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.versionnumber = versionnumber;
        return _x;
    }

    @Property(name="systemuserid")
    @JsonIgnore
    public Optional<String> getSystemuserid() {
        return Optional.ofNullable(systemuserid);
    }

    public Systemuserprofiles withSystemuserid(String systemuserid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("systemuserid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.systemuserid = systemuserid;
        return _x;
    }

    @Property(name="fieldsecurityprofileid")
    @JsonIgnore
    public Optional<String> getFieldsecurityprofileid() {
        return Optional.ofNullable(fieldsecurityprofileid);
    }

    public Systemuserprofiles withFieldsecurityprofileid(String fieldsecurityprofileid) {
        Systemuserprofiles _x = _copy();
        _x.changedFields = changedFields.add("fieldsecurityprofileid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.systemuserprofiles");
        _x.fieldsecurityprofileid = fieldsecurityprofileid;
        return _x;
    }

    public Systemuserprofiles withUnmappedField(String name, String value) {
        Systemuserprofiles _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Systemuserprofiles patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Systemuserprofiles _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Systemuserprofiles put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Systemuserprofiles _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Systemuserprofiles _copy() {
        Systemuserprofiles _x = new Systemuserprofiles();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.systemuserprofileid = systemuserprofileid;
        _x.versionnumber = versionnumber;
        _x.systemuserid = systemuserid;
        _x.fieldsecurityprofileid = fieldsecurityprofileid;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Systemuserprofiles[");
        b.append("systemuserprofileid=");
        b.append(this.systemuserprofileid);
        b.append(", ");
        b.append("versionnumber=");
        b.append(this.versionnumber);
        b.append(", ");
        b.append("systemuserid=");
        b.append(this.systemuserid);
        b.append(", ");
        b.append("fieldsecurityprofileid=");
        b.append(this.fieldsecurityprofileid);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
